@@ -14,7 +14,7 @@ from .api import Api
 import requests
 import os
 
-__version__ = "0.23.6"
+__version__ = "0.23.13"
 __github_repo = "jupyter-naas/naas"
 __doc_url = "https://naas.gitbook.io/naas/"
 __canny_js = '<script>!function(w,d,i,s){function l(){if(!d.getElementById(i)){var f=d.getElementsByTagName(s)[0],e=d.createElement(s);e.type="text/javascript",e.async=!0,e.src="https://canny.io/sdk.js",f.parentNode.insertBefore(e,f)}}if("function"!=typeof w.Canny){var c=function(){c.q.push(arguments)};c.q=[],w.Canny=c,"complete"===d.readyState?l():w.attachEvent?w.attachEvent("onload",l):w.addEventListener("load",l,!1)}}(window,document,"canny-jssdk","script");</script>'  # noqa: E501
@@ -23,8 +23,8 @@ __location__ = os.getcwd()
 scheduler = Scheduler()
 secret = Secret()
 runner = Runner()
-api = Api()
-webhook = api
+api = Api(True)
+webhook = Api()
 assets = Assets()
 dependency = Dependency()
 notifications = Notifications()
