@@ -1,12 +1,11 @@
 from IPython.core.display import display, HTML
 from .runner.proxy import encode_proxy_url
-from .types import t_delete, t_job, t_add
+from .types import t_delete, t_job, t_add, t_env
 from .runner.env_var import n_env
 import ipywidgets as widgets
 import pandas as pd
 import ipykernel
 import requests
-import errno
 import copy
 import uuid
 import os
@@ -26,24 +25,28 @@ except ImportError:
 class Manager:
     __error_busy = "Naas look busy, try to reload your machine"
     __error_reject = "Naas refused your request, reason :"
-    __production_path = None
-    __folder_name = ".naas"
     __filetype = None
     headers = None
 
     def __init__(self, filetype):
         self.headers = {"Authorization": f"token {n_env.token}"}
         self.__filetype = filetype
-        self.__production_path = os.path.join(n_env.server_root, self.__folder_name)
-        if not os.path.exists(self.__production_path):
-            try:
-                os.makedirs(self.__production_path)
-            except OSError as exc:  # Guard against race condition
-                if exc.errno != errno.EEXIST:
-                    raise
+        self.set_runner_mode()
 
     def is_production(self):
-        return False if self.notebook_path() else True
+        if "naas_env" in globals():
+            return True if naas_env == "PRODUCTION" else False  # type: ignore  # noqa: F821
+        else:
+            return False
+
+    def set_runner_mode(self):
+        try:
+            r = requests.get(
+                f"{n_env.api}/{t_env}",
+            )
+            r.raise_for_status()
+        except Exception:
+            n_env.remote_mode = not n_env.remote_mode
 
     def get(self):
         public_url = f"{encode_proxy_url()}"
@@ -64,7 +67,7 @@ class Manager:
             naas_data = r.json()
         except requests.exceptions.ConnectionError:
             print(self.__error_busy)
-        except requests.HTTPError as e:
+        except requests.exceptions.HTTPError as e:
             print(self.__error_reject, e)
         return naas_data
 
@@ -107,7 +110,7 @@ class Manager:
             return notebooks
         except requests.exceptions.ConnectionError as e:
             print(e)
-        except requests.HTTPError as e:
+        except requests.exceptions.HTTPError as e:
             print(e)
         except Exception as e:
             tb = traceback.format_exc()
@@ -156,9 +159,6 @@ class Manager:
             public_url = f"{public_url}/{token}"
         return public_url
 
-    def get_prod_path(self, path):
-        return path.replace(n_env.server_root, self.__production_path)
-
     def __open_file(self, path):
         filename = os.path.basename(path)
         if not os.path.exists(path):
@@ -167,13 +167,20 @@ class Manager:
         encoded = base64.b64encode(data)
         return {"filename": filename, "data": encoded.decode("ascii")}
 
-    def __save_file(self, path, data=None):
-        if not data:
+    def safe_filepath(self, path):
+        path = os.path.join(n_env.server_root, path)
+        return path
+
+    def __save_file(self, path, filedata=None):
+        dirname = os.path.dirname(path)
+        filename = filedata["filename"] or os.path.basename(path)
+        new_path = os.path.join(dirname, filename)
+        if not filedata:
             return
-        if not os.path.exists(path):
-            raise FileNotFoundError(f"file doesn't exist {path}")
-        f = open(path, "wb")
-        decoded = base64.b64decode(data)
+        if os.path.exists(new_path):
+            raise FileNotFoundError(f"file already exist {new_path}")
+        f = open(new_path, "wb")
+        decoded = base64.b64decode(filedata["data"])
         f.write(decoded)
         f.close()
 
@@ -181,22 +188,21 @@ class Manager:
         if not path and self.is_production():
             print("No clear_prod done you are in production\n")
             return
-        current_file = self.get_path(path)
-        prod_path = self.get_prod_path(current_file)
+        prod_path = self.get_path(path)
         try:
             r = requests.delete(
                 f"{n_env.api}/{t_job}",
-                json={"path": prod_path, "histo": histo, "mode": mode},
+                params={"path": prod_path, "histo": histo, "mode": mode},
             )
             r.raise_for_status()
             res = r.json()
             for ff in res:
-                print(f"🕣 Your Notebook output {ff} has been remove from production.\n")
+                print(f"🕣 Your file {ff} has been remove from production.\n")
             return pd.DataFrame(data=res.get("files", []))
         except requests.exceptions.ConnectionError as err:
             print(self.__error_busy, err)
             raise
-        except requests.HTTPError as err:
+        except requests.exceptions.HTTPError as err:
             print(self.__error_reject, err)
             raise
 
@@ -205,66 +211,74 @@ class Manager:
             print("No list_prod done you are in production\n")
             return
         current_file = self.get_path(path)
-        prod_path = self.get_prod_path(current_file)
         try:
             r = requests.get(
                 f"{n_env.api}/{t_job}",
-                json={"path": prod_path, "type": self.__filetype, "mode": mode},
+                params={"path": current_file, "type": self.__filetype, "mode": mode},
             )
             r.raise_for_status()
             res = r.json()
-            if res.get("files", None):
+            if res.get("files", None) and len(res.get("files", [])) > 0:
                 return pd.DataFrame(data=res.get("files", []))
             else:
-                return pd.DataFrame(data=res)
+                print("No files found in prod")
+                return []
         except requests.exceptions.ConnectionError as err:
             print(self.__error_busy, err)
             raise
-        except requests.HTTPError as err:
+        except requests.exceptions.HTTPError as err:
             print(self.__error_reject, err)
             raise
 
-    def get_file(self, path=None, mode=None):
+    def get_file(self, path=None, mode=None, histo=None):
         if not path and self.is_production():
             print("No get_prod done you are in production\n")
             return
         current_file = self.get_path(path)
         filename = os.path.basename(current_file)
-        if mode:
-            dirname = os.path.dirname(current_file)
-            filename = f"{mode}_{filename}"
-            current_file = os.path.join(dirname, filename)
-        prod_path = self.get_prod_path(current_file)
         try:
             r = requests.get(
                 f"{n_env.api}/{t_job}",
-                json={"path": prod_path, "type": self.__filetype, "mode": mode},
+                params={
+                    "path": current_file,
+                    "type": self.__filetype,
+                    "mode": mode,
+                    "histo": histo,
+                },
             )
             r.raise_for_status()
             res = r.json()
-            self.__save_file(current_file, res.get("file"))
+            self.__save_file(self.safe_filepath(current_file), res.get("file"))
             print(
-                f"🕣 Your Notebook {filename} from {mode} has been copied into your local folder.\n"
+                f"🕣 Your Notebook {mode or ''} {filename}, has been copied into your local folder.\n"
             )
-            return res
         except requests.exceptions.ConnectionError as err:
             print(self.__error_busy, err)
             raise
-        except requests.HTTPError as err:
+        except requests.exceptions.HTTPError as err:
             print(self.__error_reject, err)
             raise
 
-    def path(self, path):
-        if self.is_production():
-            return self.get_prod_path(path)
-        else:
-            return path
+    def path(self, filetype):
+        def mode_path(self, path):
+            nonlocal filetype
+            if self.is_production():
+                # filename = os.path.basename(path)
+                # dirname = os.path.dirname(path)
+                # filename = f"{filetype}_{filename}"
+                # type_path = os.path.join(dirname, filename)
+                type_path = path
+                return self.get_path(type_path)
+            else:
+                return path
+
+        return mode_path
 
     def add_prod(self, obj, debug):
         if "type" in obj and "path" in obj and "params" in obj and "value" in obj:
             new_obj = copy.copy(obj)
             dev_path = obj.get("path")
-            new_obj["path"] = self.get_prod_path(dev_path)
+            new_obj["path"] = self.get_path(dev_path)
             new_obj["file"] = self.__open_file(dev_path)
             new_obj["status"] = t_add
             try:
@@ -278,7 +292,7 @@ class Manager:
             except requests.exceptions.ConnectionError as err:
                 print(self.__error_busy, err)
                 raise
-            except requests.HTTPError as err:
+            except requests.exceptions.HTTPError as err:
                 print(self.__error_reject, err)
                 raise
             return new_obj
@@ -290,7 +304,7 @@ class Manager:
     def del_prod(self, obj, debug):
         if "type" in obj and "path" in obj:
             new_obj = copy.copy(obj)
-            new_obj["path"] = self.get_prod_path(obj.get("path"))
+            new_obj["path"] = self.get_path(obj.get("path"))
             new_obj["params"] = {}
             new_obj["file"] = None
             new_obj["value"] = None
@@ -306,7 +320,7 @@ class Manager:
             except requests.exceptions.ConnectionError as err:
                 print(self.__error_busy, err)
                 raise
-            except requests.HTTPError as err:
+            except requests.exceptions.HTTPError as err:
                 print(self.__error_reject, err)
                 raise
             return new_obj
